@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -27,7 +26,7 @@
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "gtk-utils.h"
-#include "main.h"
+#include "fr-init.h"
 #include "fr-window.h"
 
 
